Module body

Traits and structures to aid consuming and writing HTTP payloads.

Structs

BodyStream
Type represent streaming body.
BoxedBodyStream
Type represent streaming body. Response does not contain content-length header and appropriate transfer encoding is used.
SizedStream
Type represent streaming body. This body implementation should be used if total size of stream is known. Data get sent as is without using transfer encoding.

Enums

Body
Represents various types of http message body.
BodySize
Body size hint
ResponseBody
Represents http response body

Traits

MessageBody
Interface for types that can be streamed to a peer.