Traits and structures to aid consuming and writing HTTP payloads.
Structs
- Body
Stream - Type represent streaming body.
- Boxed
Body Stream - Type represent streaming body.
Response does not contain
content-lengthheader and appropriate transfer encoding is used. - Sized
Stream - Type represent streaming body. This body implementation should be used if total size of stream is known. Data get sent as is without using transfer encoding.
Enums
- Body
- Represents various types of http message body.
- Body
Size - Body size hint
- Response
Body - Represents http response body
Traits
- Message
Body - Interface for types that can be streamed to a peer.